[−][src]Crate serde_xmlrpc
Structs
| Fault | A |
Enums
| Error | Errors that can occur when trying to perform an XML-RPC request. |
| Value |
Functions
| request_to_string | |
| response_from_str | |
| value_from_str | |
| value_to_string |
Type Definitions
| Result |
| Fault | A |
| Error | Errors that can occur when trying to perform an XML-RPC request. |
| Value |
| request_to_string | |
| response_from_str | |
| value_from_str | |
| value_to_string |
| Result |